@charset "utf-8";
/**
 * @framework	CFF - Classy Frontend Framework
 * @author		Angelo Dini
 * @copyright	http://www.divio.ch under the BSD Licence
 */

/*##################################################|*/
/* #BASE# */
.plugin_gallery { margin:0 0 15px; position:relative; left:0; top:0; z-index:10; }

/* gallery canvas */
.gallery-canvas { position:relative; left:0; top:0; z-index:20; margin:0; overflow:hidden; }
.gallery-canvas .gallery-list { list-style:none; padding:0; margin:0; }
.gallery-canvas .gallery-list .gallery-list-slide { padding:0; margin:0; zoom:1; width:100%; }
.gallery-canvas .gallery-list .gallery-item { text-align:center; }

.gallery-thumbs { display:none; }
.gallery-thumbs ul { position:relative; left:0; top:0; z-index:20; list-style:none; padding:0; margin:0; }
.gallery-thumbs ul li { padding:0; margin:0; }

.gallery-controls { display:none; padding:0; margin:0; }
.gallery-controls .gallery-ctrl-play,
.gallery-controls .gallery-ctrl-pause { display:inline; }
.gallery-controls .active { display:none; }

.gallery-caption { display:none; }

/*##################################################|*/
/* #CUSTOM# */
.gallery-canvas .gallery-list .gallery-item { padding-right:5px; }

.gallery-thumbs {}
.gallery-thumbs ul { text-align:center; display:none; }
.gallery-thumbs ul li { float:left; display:inline-block; }
.gallery-thumbs ul li a { float:left; display:inline-block; padding:0 5px; }
.gallery-thumbs ul li a:hover { background-position:left bottom; }

.gallery-thumbs ul li.gallery-thumbs-prev a {}
.gallery-thumbs ul li.gallery-thumbs-next a {}
.gallery-thumbs ul li.gallery-thumbs-next a:hover,
.gallery-thumbs ul li.gallery-thumbs-prev a:hover {}

.gallery-thumbs ul li.active a {}

/* #CUSTOM/lite# */