{% extends "simplegallery/gallery_plugin.html" %}
{% load i18n sekizai_tags %}

{% block gallery_css %}plugin_gallery-lite{% endblock %}

{% block galery_options %}
{% addtoblock "js" %}
<script type="text/javascript">
//<![CDATA[
jQuery(document).ready(function ($) {

	new Cl.Gallery('#plugin_gallery-{{ instance.id }}', {
		fx: 'fade',
		timeout: {{ instance.interval }}*1000,
		ui: {
			caption: false,
			controls: false,
			thumbnails: false
		},
		plugins: {
			external: false,
			keycontrol: false,
			lightbox: false,
			lightboxOptions: {}
		}
	});

});
//]]>
</script>
{% endaddtoblock %}
{% endblock %}